import pytest
from pdfsearch.tagging import Tagger
import os


@pytest.fixture
def setup_tagger():
    if os.path.isfile("/tmp/___dbfile"):
        os.remove("/tmp/___dbfile")
    tagger = Tagger("/tmp/___dbfile")
    yield tagger


def test_create_tag(setup_tagger: Tagger):
    tagger = setup_tagger
    assert tagger.available_tags() == []
    assert tagger.create_tag("test") == "1"
    assert tagger.create_tag("test2") == "2"
    assert tagger.available_tags() == ["test", "test2"]


def test_delete_tag(setup_tagger: Tagger):
    tagger = setup_tagger
    file = "/tmp/test_pdf/001_Booster - Robustness.pdf"
    tagger.create_tag("test")
    tagger.add_tags_to_file(file, "test")
    assert tagger.available_tags() == ["test"]
    tagger.delete_tag("test")
    assert tagger.available_tags() == []
    assert tagger.tags_for_file(file) == []


def test_add_tags_for_file(setup_tagger: Tagger):
    tagger = setup_tagger
    file = "/tmp/test_pdf/001_Booster - Robustness.pdf"
    tagger.add_tags_to_file(file, ["taga", "tagb"])
    assert tagger.tags_for_file(file) == ["taga", "tagb"]
    tagger.add_tags_to_file(file, ["tagc"])
    assert tagger.tags_for_file(file) == ["taga", "tagb", "tagc"]


def remove_tag_from_file(setup_tagger: Tagger):
    tagger = setup_tagger
    file = "/tmp/test_pdf/001_Booster - Robustness.pdf"
    tagger.add_tags_to_file(file, "test")
    assert tagger.tags_for_file(file) == ["test"]
    tagger.remove_tags_from_file(file, "test")
    assert tagger.tags_for_file(file) == []


def test_query_tag_for_file(setup_tagger: Tagger):
    tagger = setup_tagger
    file = "/tmp/test_pdf/001_Booster - Robustness.pdf"
    assert tagger.tags_for_file(file) == []
    tagger.add_tags_to_file(file, ["taga", "tagb"])
    assert tagger.tags_for_file(file) == ["taga", "tagb"]
